# frozen_string_literal: true

$LOAD_PATH << File.join(File.dirname(File.dirname(File.dirname(File.dirname(__dir__)))), 'vendor/gems/ipfs/lib')
require 'ipfs/client'

module Crossbelt
  module Plugins
    module Exporters
      class Ipfs
        def self.type
          'exporter'
        end

        def self.version
          '0.0.1'
        end

        def self.name
          'ipfs'
        end

        def self.description
          'Outputs data on IPFS file system'
        end

        def self.to_h
          {
            name: name,
            type: type,
            version: version,
            desc: description
          }
        end

        def self.export(file: nil, contents: nil)
          raise ArgumentError unless file || contents

          begin
            if contents
              file = Tempfile.new
              File.write(file, contents)
            end
            new.add(file)
          ensure
            file.close if file.is_a?(Tempfile)
          end
        end

        def client
          @client ||= IPFS::Client.default
        end

        def pin_rm(node)
          JSON.parse client.pin_rm(node)
        end

        def read(node)
          client.cat(node)
        end

        def ls(node)
          client.ls(node)
        end

        def add(file)
          node = client.add(File.expand_path(file))
          node.hashcode
        end
      end
    end
  end
end
